# Generated by Django 3.2 on 2021-04-28 04:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0013_netbox_bgp'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='asngroup',
            name='slug',
        ),
    ]
