{% extends 'generic/object_list.html' %}

{% block extra_controls %}
{% if permissions.add %}
<a href="{% url 'plugins:netbox_bgp:routing_policy_add' %}" class="btn btn-sm btn-success">
    <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add
</a>
{% endif %}
{% endblock %}
{% block bulk_buttons %}
{% if permissions.delete %}
<button type="submit" name="_delete" formaction="{% url 'plugins:netbox_bgp:routing_policy_bulk_delete' %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-danger btn-sm">
    <span class="mdi mdi-trash-can-outline" aria-hidden="true"></span> Delete Selected
</button>
{% endif %}
{% endblock %}