# Generated by Django 3.1.3 on 2021-04-21 05:11

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0007_netbox_bgp'),
    ]

    operations = [
        migrations.CreateModel(
            name='BGPPeerGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('created', models.DateField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('name', models.CharField(max_length=100)),
                ('slug', models.SlugField(max_length=100)),
                ('description', models.CharField(blank=True, max_length=200)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterField(
            model_name='asn',
            name='number',
            field=models.PositiveBigIntegerField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(4294967294)]),
        ),
        migrations.AlterField(
            model_name='community',
            name='number',
            field=models.PositiveBigIntegerField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(4294967294)]),
        ),
        migrations.AddField(
            model_name='bgpsession',
            name='peer_group',
            field=models.ManyToManyField(blank=True, null=True, to='netbox_bgp.BGPPeerGroup'),
        ),
    ]
