# Generated by Django 3.1.3 on 2021-04-21 05:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0008_netbox_bgp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bgpsession',
            name='peer_group',
            field=models.ManyToManyField(blank=True, to='netbox_bgp.BGPPeerGroup'),
        ),
    ]
