# Generated by Django 3.1.3 on 2021-04-06 10:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0122_standardize_name_length'),
        ('netbox_bgp', '0003_netbox_bgp'),
    ]

    operations = [
        migrations.AddField(
            model_name='bgpsession',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, to='dcim.device'),
        ),
    ]
