# Generated by Django 3.2.11 on 2022-01-08 15:20

from django.db import migrations
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('extras', '0067_customfield_min_max_values'),
        ('netbox_bgp', '0019_netbox_bgp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='asn',
            name='tags',
            field=taggit.managers.TaggableManager(related_name='asn_tags', through='extras.TaggedItem', to='extras.Tag'),
        ),
    ]
