# Generated by Django 3.2 on 2021-04-27 06:18

from django.db import migrations, models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        #('extras', '0059_exporttemplate_as_attachment'),
        ('netbox_bgp', '0010_netbox_bgp'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoutingPolicy',
            fields=[
                ('created', models.DateField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('id', models.BigAutoField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=100)),
                ('slug', models.SlugField(max_length=100)),
                ('description', models.CharField(blank=True, max_length=200)),
                ('tags', taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag')),
            ],
            options={
                'verbose_name_plural': 'Routing policies',
            },
        ),
        migrations.AddField(
            model_name='bgppeergroup',
            name='export_policies',
            field=models.ManyToManyField(blank=True, related_name='group_export_policies', to='netbox_bgp.RoutingPolicy'),
        ),
        migrations.AddField(
            model_name='bgppeergroup',
            name='import_policies',
            field=models.ManyToManyField(blank=True, related_name='group_import_policies', to='netbox_bgp.RoutingPolicy'),
        ),
        migrations.AddField(
            model_name='bgpsession',
            name='export_policies',
            field=models.ManyToManyField(blank=True, related_name='session_export_policies', to='netbox_bgp.RoutingPolicy'),
        ),
        migrations.AddField(
            model_name='bgpsession',
            name='import_policies',
            field=models.ManyToManyField(blank=True, related_name='session_import_policies', to='netbox_bgp.RoutingPolicy'),
        ),
    ]
