# Generated by Django 3.2.8 on 2021-11-02 13:23

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0018_netbox_bgp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='asn',
            name='number',
            field=models.PositiveBigIntegerField(validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(4294967295)]),
        ),
    ]
