# Generated by Django 3.2 on 2021-05-25 14:35

import django.core.serializers.json
from django.db import migrations, models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        #('extras', '0059_exporttemplate_as_attachment'),
        ('netbox_bgp', '0017_netbox_bgp'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bgppeergroup',
            options={'verbose_name_plural': 'Peer Groups'},
        ),
        migrations.AddField(
            model_name='bgppeergroup',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
        migrations.AddField(
            model_name='bgppeergroup',
            name='tags',
            field=taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag'),
        ),
        migrations.AlterUniqueTogether(
            name='bgppeergroup',
            unique_together={('name', 'description')},
        ),
    ]
